@@ -1,3 +1,10 @@
+#
+# Like what you see? Join us!
+# https://www.univention.com/about-us/careers/vacancies/
+#
+# SPDX-FileCopyrightText: 2024 Univention GmbH
+# SPDX-License-Identifier: AGPL-3.0-only
+
 import subprocess
 from os import environ
 from pipes import quote
@@ -67,13 +74,13 @@ def wait_for_processes_to_finish(processes: Iterable[subprocess.Popen]) -> None:
 
 def log_warnings_about_unreachable_repository_servers(servers_with_curl_processes: Iterable[Tuple[str, subprocess.Popen]]) -> None:
     """
-    Load a message for all failed processes.
+    Log a message for all failed processes.
 
     :param processes: List of 2-tuples (URL, process)
     """
     for server, process in servers_with_curl_processes:
         if process.returncode != 0:
-            stdout, strerr = process.communicate()
+            stdout, _strerr = process.communicate()
             MODULE.warn(
                 "'%s' exited with returncode %s: %s" % (
                     " ".join(quote(arg) for arg in cast(Iterable[str], process.args)),
